<?php

/**
 * Fired during plugin activation
 *
 * @link       https://www.chiptuningreseller.com
 * @since      3.0.0
 *
 * @package    Ctr
 * @subpackage Ctr/includes
 */
require_once 'class-ctr-db.php';

/**
 * Fired during plugin activation.
 *
 * This class defines all code necessary to run during the plugin's activation.
 *
 * @since      3.0.0
 * @package    Ctr
 * @subpackage Ctr/includes
 * @author     M Bos <support@chiptuningreseller.com>
 */

class Ctr_Updator
{
    private $database;
    private $currentVersion;
    private $newVersion;

    /**
     * Initialize the class and set its properties.
     *
     * @since    3.3.9.6
     * @param      string    $plugin_name       The name of this plugin.
     * @param      string    $version    The version of this plugin.
     */
    public function __construct($currentVersion, $newVersion)
    {
        $this->currentVersion = $currentVersion;
        $this->newVersion = $newVersion;
        $this->database = new Ctr_DB();
    }

    public function runUpdates() {
        $this->check_seo_settings_column();
        $this->update_template_folders();
    }


    /**
     * @since 3.3.9.6
     * Check if our SEO Settings Column has already been added. If not, add it.
     */
    public function check_seo_settings_column()
    {
        global $wpdb;
        $row = $wpdb->query("SHOW COLUMNS FROM `{$wpdb->prefix}chiptuningreseller` LIKE 'seo_settings'");
        if (null == $row) {
            $wpdb->query("ALTER TABLE {$wpdb->prefix}chiptuningreseller ADD `seo_settings` MEDIUMTEXT NULL AFTER `layout_settings`");
        }
    }

    public function update_template_folders()
    {
        /**
         * Check if the templates have been copied to the new custom_templates location
         * First check if the folder exists
         * Then check if the customer already made copies to their theme folder
         * Then copy the templates to the correct folder
         * 
         * This will prevent losing template changes when updating or changing a theme!
         */
        $custom_template_folder = wp_upload_dir()['basedir'] . '/ctr/custom_templates';
        $custom_template_theme_folder = get_stylesheet_directory() . '/chiptuningreseller';

        if (!is_dir($custom_template_folder)) {
            // Also check if the custom CSS has been set in the database. We need to make sure we also copy that upon installation
            $database = new Ctr_DB();
            $settings = $database->getSettings();
            if (isset($settings['custom_css'])) {
                $custom_css_backup = $settings['custom_css'];
            }

            require_once plugin_dir_path(__FILE__) . 'class-ctr-templator.php';
            $templator = new CTR_Templator();
            $src_folder = null;

            if (is_dir($custom_template_theme_folder)) {
                $src_folder = $custom_template_theme_folder;
            }

            $copied = $templator->copy_templates($custom_template_folder, $src_folder, true);
            $copied = $templator->copy_templates($custom_template_folder, null, true);

            if (isset($custom_css_backup)) {
                $custom_css_backup =  "/** THIS IS A BACKUP FROM YOUR OLD CSS THAT WAS STORED IN THE CTR DATABASE. PLEASE ADD IT TO YOUR NEW CSS IF NEEDED **/\r\n" . $custom_css_backup;
                file_put_contents($custom_template_folder . '/css/backup_old_css.css', $custom_css_backup);
            }

            if ($copied != false) {
                if ($copied === 0) {
                    echo "\r\nDue to an update your template files have been copied to a new folder: " . $custom_template_folder . " - edit your templates in the ChiptuningReseller plugin TEMPLATE EDITOR";
                }
            }
        }
    }
}
